#
# spec file for package mediastreamer2
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _name   mediastreamer
%define sobase  libmediastreamer_base
%define sovoip  libmediastreamer_voip
%define sover   7
%bcond_without ffmpeg
Name:           mediastreamer2
Version:        2.14.0
Release:        3.5
Summary:        Audio/Video real-time streaming
License:        GPL-2.0+
Group:          Productivity/Telephony/Utilities
Url:            https://www.linphone.org/technical-corner/mediastreamer2/overview
Source:         https://linphone.org/releases/sources/%{_name}/%{_name}-%{version}.tar.gz
Source99:       baselibs.conf
# PATCH-FIX-OPENSUSE mediastreamer2-bctoolbox-pkgconfig.patch sor.alexei@meowr.ru -- Add bctoolbox dependency to mediastreamer.pc.
Patch0:         mediastreamer2-bctoolbox-pkgconfig.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gawk
BuildRequires:  gcc-c++
BuildRequires:  intltool
BuildRequires:  libgsm-devel
BuildRequires:  libpcap-devel
BuildRequires:  libsrtp-devel
BuildRequires:  libtool
BuildRequires:  libv4l-devel
BuildRequires:  libvpx-devel
BuildRequires:  pkgconfig
BuildRequires:  spandsp-devel
BuildRequires:  vim
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(bctoolbox)
BuildRequires:  pkgconfig(libbzrtp) >= 1.0.4
BuildRequires:  pkgconfig(libebml)
BuildRequires:  pkgconfig(libmatroska)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libupnp)
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(ortp) >= 0.27.0
BuildRequires:  pkgconfig(speex)
BuildRequires:  pkgconfig(speexdsp)
BuildRequires:  pkgconfig(theora)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xv)
Recommends:     %{name}-lang
%if %{with ffmpeg}
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(libavcodec) >= 51.0.0
BuildRequires:  pkgconfig(libswscale) >= 0.7.0
%endif

%description
Mediastreamer2 is a GPL licensed library to make audio and video
real-time streaming and processing. Written in pure C, it is based
upon the oRTP library.

%lang_package

%package -n %{sobase}%{sover}
Summary:        Audio/video real-time streaming library, base part
Group:          System/Libraries

%description -n %{sobase}%{sover}
Mediastreamer2 is a GPL licensed library to make audio and video
real-time streaming and processing. Written in pure C, it is based
upon the oRTP library.

%package -n %{sovoip}%{sover}
Summary:        Audio/video real-time streaming library, voip part
Group:          System/Libraries

%description -n %{sovoip}%{sover}
Mediastreamer2 is a GPL licensed library to make audio and video
real-time streaming and processing. Written in pure C, it is based
upon the oRTP library.

%package devel
Summary:        Headers, libraries and docs for the mediastreamer2 library
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       %{sobase}%{sover} = %{version}
Requires:       %{sovoip}%{sover} = %{version}

%description devel
Mediastreamer2 is a GPL licensed library to make audio and video
real-time streaming and processing. Written in pure C, it is based
upon the ortp library.

This package contains header files and development libraries needed to
develop programs using the mediastreamer2 library.

%prep
%setup -q -n %{_name}-%{version}
%patch0 -p1

%build
NOCONFIGURE=1 ./autogen.sh
%configure \
  --enable-external-ortp    \
  --enable-zrtp             \
%if %{without ffmpeg}
  --disable-non-free-codecs \
  --disable-video           \
%endif
  --disable-strict          \
  --disable-static
make %{?_smp_mflags} V=1

%install
%make_install

%find_lang %{_name}
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{sobase}%{sover} -p /sbin/ldconfig

%postun -n %{sobase}%{sover} -p /sbin/ldconfig

%post -n %{sovoip}%{sover} -p /sbin/ldconfig

%postun -n %{sovoip}%{sover} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc AUTHORS COPYING NEWS README
%{_bindir}/mediastream
%{_bindir}/msaudiocmp
%dir %{_datadir}/images/
%{_datadir}/images/nowebcamCIF.jpg

%files lang -f %{_name}.lang
%defattr(-,root,root)

%files -n %{sobase}%{sover}
%defattr(-,root,root)
%{_libdir}/%{sobase}.so.%{sover}*

%files -n %{sovoip}%{sover}
%defattr(-,root,root)
%{_libdir}/%{sovoip}.so.%{sover}*

%files devel
%defattr(-,root,root)
%{_includedir}/mediastreamer2/
%{_libdir}/libmediastreamer_*.so
%{_libdir}/pkgconfig/mediastreamer.pc

%changelog
* Thu Sep 29 2016 sor.alexei@meowr.ru
- Add mediastreamer2-bctoolbox-pkgconfig.patch: Add bctoolbox
  dependency to mediastreamer.pc.
* Mon Sep 12 2016 sor.alexei@meowr.ru
- Update to version 2.14.0 (changes since 2.12.1):
  * Add support of the H.264 hardware codec on Apple's platforms.
  * MSFactory usage: Using one MSfactory per LinphoneCore instance,
    deprecate all "static" methods, now grouped around the
    MSFactory object.
  * Add BroadVoice16 audio codec support.
  * Fix option to really disable libv4l2 when asked.
  * Bugfixes.
* Mon Jul 25 2016 olaf@aepfle.de
- Build with ffmpeg unconditional
* Wed Jun 22 2016 sor.alexei@meowr.ru
- Enable more additional build requirements.
* Fri Mar  4 2016 sor.alexei@meowr.ru
- Update to 2.12.1:
  * Fix crash in MKV recorder.
  * Fix I-frame request when starting MKV recording.
- Use tarball signing.
* Fri Nov  6 2015 sor.alexei@meowr.ru
- Update to 2.12.0:
  * Allow video stream to keep its source (camera).
  * Basic AVPF handling for H.264 codec.
  * Support of video presets (include a high-fps preset).
  * Support of RTP session as input/output of a audio/video stream
    (instead of a sound card or camera/display).
  * Add text stream for RTT (Real-Time Text).
  * Support of VP8 recording/playing in mkv files.
  * Bug fixes.
* Mon Sep 21 2015 olaf@aepfle.de
- Use pkgconfig for ffmpeg to fix build in PMBS
* Tue Sep  8 2015 sor.alexei@meowr.ru
- Build with video support outside PMBS for openSUSE Leap 42.1
  and newer (where ffmpeg is available).
- Split locales into mediastreamer2-lang.
* Sat Aug 22 2015 tbechtold@suse.com
- Use correct tar.gz file (verified signature)
* Fri Aug 21 2015 tbechtold@suse.com
- update to 2.11.2:
  * Fix build without non free codecs when building with CMake.
  * Minor release v2.11.2
  * Fix nowebcam not working with valid JPG
  * Fix issue when detecting fast CPUs on Android
  * Fix missing return on isArmv7 method for Android
  * add method to obtain the list of supported abis
  * bc_tester_utils.h: fix some macros
  * Always include static picture camera.
  * The nowebcam filter now sends a black image if the jpeg file is not found
    or if the platform does not support jpeg decoding.
  * Fix HAVE_NON_FREE_CODECS for Android
  * Fix compilation errors and memory leak.
  * Fix last commit to clean incomplete frames correctly.
  * Request sending of RPSI when a VP8 decoded frame is a golden or an altref
    frame.
  * Update ICE session state when removing a check list.
  * msvideo.c: use ms_debug instead of ms_message
  * Revert "zrtp.c: avoid copying/logging non-NULL-terminated string"
  * bc_tester_utils.h: fix missing stdarg.h
  * configure.ac: use -Wno-unused-function when using clang
  * bc_tester_utils: fix include paths
  * tester: update bc_tester_utils
  * Updated Version.java with android lollipop api codes
  * Always look for polarssl when building with CMake (needed for STUN hmac).
  * Add option to enable/disable documentation generation when building with
    CMake.
  * fix crash because of virtual refbase of AudioTrack not detected properly,
    due to reverse loop starting past end of buffer.
  * mediastreamer2_adaptive_tester.c: disable stateful tests for yet
  * Set picture format when changing camera with a source that performs
    encoding.
  * Edit previous driver log instead of adding a new one
  * Log v4l2 driver name and version
  * fix previous commit
  * workaround attempt for buggy v4l2 drivers
  * alsa.c: output logs in ORTP_MESSAGE level instead of ORTP_ERROR
  * Do not try to search for libgcc and libmingwex when building for Windows
    Phone.
  * change stupid error message into normal log.
  * configure.ac: add --enable-tools option as Linphone does
  * configure.ac: add --disable-documentation option to speed up dev builds
  * alsa.c: set error log handler in order to use ms_error instead of stderr
  * Improve the documentation of the video_preview_stop_reuse_source() function.
  * Release 2.11.1
  * zrtp.c: avoid copying/logging non-NULL-terminated string
  * both vp8 & srtp are now available on centos7, enabling for rpm
  * mediastreamer2_tester_ios.m: use ms_strdup when setting writable/readable
    directories
  * Revert crappy AEC on galaxy note - it works well generally.
  * fix stereo support again
  * fix bugs with stereo support, when encoder/decoder doesn't tell what
    number of channel is. Fix crash under vmware when msv4l2.c leaves buffers
    queued before closing.
  * Fix build with Visual Studio.
  * switch rtp destination port using received stun packet in case of symmetric
    rtp and no rtp packets received yet
  * avoid extern variable for windows
  * modified ms_zrtp_startSrtpSession to support either b256 or b32 format
    SAS string
  * allow code to work without speex resampler
  * prepare work to have symmetric rtp based on stun packet
  * tester: fix crash when using both --verbose and --log-file
  * do not retry forever to open x11/xv
  * add video stream getter on cam
  * tester: use snprintf instead of sprintf and use stdio instead of default
    logger function for bc_tester_utils
  * Fix build with CMake for Windows Phone.
  * fix broken rtcp encryption
  * Fix potential CMake error with missing arguments.
  * Add build of VP8 on Windows Phone 8.
  * bc_tester_utils.c: use tester_printf instead of fprintf
  * mediastreamer2_tester.c: correctly set log level mask
  * Set the picture format of the source when it performs the encoding.
  * Define MS_PIX_FMT_UNKNOWN first so that its value does not change when
    adding pictures formats.
  * mediastream.c: use strtol instead of atoi because of Windows not
    handling ERANGE
  * qos analyzer: add some comments
  * Add the video_stream_started() function.
  * Fix build of tester with CMake.
  * fix compilation problem
  * tester: update common & add common/ subfolder in include directories
  * mediastream_cocoa.m: use dispatch_get_global_queue instead of
    dispatch_get_main_queue in order to display windows without blocking
    the main queue
  * fix bugs in outgoing metadata support
  * add support of outgoing metadatas
  * add method to bufferizer to put meta datas to a message
  * videostream.c: remove unnecessary \n in ms_log functions
  * mediastream_cocoa.m: use display_async instead of
    performSelectorInBackground, otherwise nanosleeps are not respected
    by Darwin... (+reformat tabs)
  * fix ios compilation issue
  * autocompletion: add Linphone and mediastreamer tools as supported by
    the tool
  * fix IOS compilation
  * mediastream.c tool: improve helper and remote IP parsing when only port
    is provided (assume localhost)
  * Add ms_snd_card_manager_prepend_cards() API.
  * Tester: update CMakeLists.txt and use latest changes
  * make a better mire, which is harder to process by video encoders
  * adaptive tester: use MIR camera instead of the default one to get a
    reproductible scenario environment
  * set correct ortp requirement
  * Tester: fix return value
  * adaptive tester: disable camera optimization when using no webcam
  * adaptive tester: use MIR camera instead of the real one
  * Tester: fix utils
  * .gitignore: ignore generated executable pcap_playback
  * mediastreamer2_tester: use ORTP_MESSAGE as verbosity level
  * Tester: update
  * Tester: terminate tester_utils for mediastreamer2
  * Tester: create tester_utils which contain factorized code for all
    testers (in progress, continuing)
  * Tester: create tester_utils which contain factorized code for all
    testers (in progress, continuing)
  * Tester: create tester_utils which contain factorized code for all
    testers (in progress, continuing)
  * Tester: create tester_utils which contain factorized code for all
    testers (in progress)
  * tester: rename mediastream_tester_cocoa.m to mediastreamer2_tester_cocoa.m
    to get a more consistent name convention
  * Add test for TMMBR feedback messages.
  * fix compilation issue
  * fix ms2 build without srtp
  * Fix crash
  * Allow x86_64 simulator ios compilation
  * Fix "AVPF RPSI count" test where the required bitrate was not initialized.
  * Do not force computation of send bandwidth in the test, it is done
    automatically by oRTP.
  * Include missing CheckSymbolExists.
- Adjust Requires according to configure.ac
* Sun Apr  5 2015 fisiu@opensuse.org
- Build with zrtp support: fix boo#903431.
* Mon Mar 23 2015 sor.alexei@meowr.ru
- Add zRTP encryption support.
- Add baselibs.conf.
* Mon Mar 16 2015 sor.alexei@meowr.ru
- Update to 2.11.0:
  * Support of AVPF with VP8 codec only.
  * Support of Matroska file format (needs libmatroska2).
  * Audio/video stream recorder. Only H264 is supported for video
    stream.
  * Add functions to the API to send audio/video streams read from
    a file (only WAV and MKV file formats are supported).
  * Add functions to the API to play multimedia files and display
    to a specified drawing surface.
  * Support of multicast IP addresses.
- Spec cleanup.
* Mon Mar 16 2015 dimstar@opensuse.org
- Add pkgconfig(speexdsp) BuildRequires: it's an explicit
  dependency according to configure; speexdsp was split off of
  libspeex into an own package.
* Sun May 25 2014 fisiu@opensuse.org
- Update to 2.10.0:
  * add HD video support
  * new OpenSLES android sound module
  * update android AEC settings table
  * add opus codec
  * bugfixes
- Build with opus audio codec and upnp support.
* Sun May 25 2014 crrodriguez@opensuse.org
- Use LFS_CFLAGS in 32 bit systems, a mediastreamer without
  large file support is not very pleasant..
- Make the build verbose.
* Mon Aug 12 2013 fisiu@opensuse.org
- Add missing BuildRequires for Video support.
* Tue Jun 25 2013 fisiu@opensuse.org
- Update to 2.9.0:
  * Add support of ICE (RFC 5245).
  * Split the libmediastreamer library in two libraries:
    libmediastreamer_base and libmediastreamer_voip. For VoIP
    support, both libraries must be linked to the executable.
  * API change to the audio_stream_new, video_stream_new,
    audio_stream_start_full, video_stream_start functions to use
    different addresses for RTP and RTCP.
  * Add accessors to set DSCP parameters for media streams.
  * AudioStream recording feature added
  * OpenGL video output for Linux
  * Adaptive bitrate control improvements
  * faster call quality indicator feedback
  * stereo support for L16 codec
- Drop 0001-Fixes-for-new-versions-of-ffmpeg.patch: fixed upstream.
* Mon Jun  3 2013 fisiu@opensuse.org
- Add 0001-Fixes-for-new-versions-of-ffmpeg.patch: fix for new
  ffmpeg API.
- Spec cleanup.
- Call ldconfig for shared library.
- Enable conditional build for "video" configure option.
* Tue Oct 23 2012 jengelh@inai.de
- Implement shared library package
- Language files are named mediastreamer.mo, adjust %%find_lang
* Wed Oct 10 2012 mailaender@opensuse.org
- initial packaging
